# eric7.EricWidgets.EricPasswordMeter

Module implementing a custom widget indicating the strength of a password.

### Global Attributes

app
meter

### Classes

EricPasswordMeter | Class implementing a custom widget indicating the strength of a password.

### Functions

None

## EricPasswordMeter

Class implementing a custom widget indicating the strength of a password.

### Derived from

QProgressBar

### Class Attributes

None

### Class Methods

None

### Methods

EricPasswordMeter | Constructor
checkPasswordStrength | Public slot to check the password strength and update the progress bar accordingly.
setMaximum | Public method to set the maximum value.
setMinimum | Public method to set the minimal value.
setValue | Public method to set the value.

### Static Methods

None

#### EricPasswordMeter (Constructor)

EricPasswordMeter(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### EricPasswordMeter.checkPasswordStrength

checkPasswordStrength(password)

Public slot to check the password strength and update the progress bar accordingly.

password (str)
  password to be checked

#### EricPasswordMeter.setMaximum

setMaximum(_value)

Public method to set the maximum value.

Overwritten to do nothing.

_value (int)
  maximum value (unused)

#### EricPasswordMeter.setMinimum

setMinimum(_value)

Public method to set the minimal value.

Overwritten to do nothing.

_value (int)
  minimum value (unused)

#### EricPasswordMeter.setValue

setValue(_value)

Public method to set the value.

Overwritten to do nothing.

_value (int)
  value (unused)

Up